@@ -521,18 +521,17 @@ foreach $archive (@ARGV) {
 #
 # See if the correct number of files were built:
 #
-    my $n_files_updated = n_files;
-    rename '.makepp/log' => '.makepp/log.failed';
-				# Get rid of the log file so we don't
-				# get confused if the next test doesn't make
-				# a log file for some reason.
-    defined($n_files_updated) or push @errors, '.makepp/log';
-
-    if (open my $n_files, 'answers/n_files' ) { # Count of # of files updated?
+    if( !defined( my $n_files_updated = n_files )) {
+      push @errors, '.makepp/log';
+    } elsif( open my $n_files, 'answers/n_files' ) { # Count of # of files updated?
       $_ = <$n_files>;
       $_ eq $n_files_updated or push @errors, 'n_files';
     }
 
+# Get rid of the log file so we don't get confused if the next test doesn't
+# make a log file for some reason.  For a failed test it remains, hence the name.
+    rename '.makepp/log' => '.makepp/log.failed';
+
 #
 # Also search through the log file to make sure there are no Perl messages
 # like "uninitialized value" or something like that.
